#!/bin/bash

set -e
set +x

declare PKG PREFIX
PKG=mcsh
PREFIX=install

declare -a make_opts
make_opts=( --quiet )

_find_files() { find "$1" -name '*.in' | sed -e "s,^$1/,," -e 's,\.in$,,'; }
find_files() { _find_files "$@" | xargs echo; }
find_tools() { find_files "src" | sed -e "s,^[^/]*/,,g"; }
find_cats() { find_files "src" | grep -v '/' | sed -e "s,^/*,," | sort -u; }


declare tools cats apps libs
cats=$(find_cats)
tools=$(find_tools)
apps=$(find_files 'src')
libs=$(find_files 'libs')

# Create system.i7, as Makefile.i7 depends on it
touch system.i7 site.i7

# Create Makefile.i7
cat >Makefile.i7<<EOF
PKG = $PKG
RUNTIME = $PKG
VERSION = unknown
AUTHOR = unknown
URL = unknown
SUPPORT_EMAIL = unknown
SUPPORT_NAME = unknown
PREFIX = $PREFIX
EXEC_PREFIX = $PREFIX
DATA_PREFIX = $PREFIX
CATS = $cats
APPS = $apps
TOOLS = $tools
ALIBS = $libs
EOF

run() { echo "$@" >&2; "$@"; }

# Create system.i7 file
run make dev-config

# avoid rebuilding Makefile.i7 or license again due to new system.i7
run mkdir -p obj/gen/libs
run touch Makefile.i7 libs/core/license-parts.in

# Install i7 which will be detected during next build
run make "${make_opts[@]}" install

# Force Makefile.i7 to regenerate
run rm Makefile.i7

# Rebuild and install everything
run make "${make_opts[@]}" install
